### Dimensions

The _Dimensions_ section does not affect the font but serves as a notepad where the dimensions of common font features can be written down and referenced.
Enter a value by clicking a number or an empty field (“--”).
Values are stored per master.
The fields change according to the script attributed to the glyph.
It can be changed through “Edit” → “Info for Selection” (Cmd-Shift-I).